//
//  FluffView.swift
//  Runner
//
//  Created by Grigori on 7/14/20.
//

import Foundation

public class EmojiView: NSObject, FlutterPlatformView {
    let frame: CGRect
    let viewId: Int64
    let args: Any?

    init(_ frame: CGRect, viewId: Int64, args: Any?){
        self.frame = frame
        self.viewId = viewId
        self.args = args
    }

    public func view() -> UIView {
        var text: String?
        var placeholder: String?
        var fontSize: Int?
        
        if let args = args as? [String: Any]{
          text = args["text"] as? String
          placeholder = args["placeholder"] as? String
            fontSize = args["fontSize"] as? Int
        }

        let textField = EmojiTextField(frame: frame)
        textField.text = text
        textField.placeholder = placeholder
        
        if let fontSize = fontSize{
            textField.font = UIFont.systemFont(ofSize: CGFloat(fontSize))
        }
        
        return textField
    }
    

}


class EmojiTextField: UITextField {
    // required for iOS 13
    override var textInputContextIdentifier: String? { "" } // return non-nil to show the Emoji keyboard ¯\_(ツ)_/¯

    override var textInputMode: UITextInputMode? {
        for mode in UITextInputMode.activeInputModes {
            if mode.primaryLanguage == "emoji" {
                return mode
            }
        }
        return nil
    }
}

